import Qt 4.7

Rectangle {
    width: 300
    height: 400

    // Top part, contains a text input and Submit button.
    // Width follows parent, height is fixed
    // filterArea.message is updated when Submit-button is pressed
    FilterArea {
        id: filterArea
        anchors.top: parent.top
        anchors.left: parent.left
        anchors.right: parent.right
        height: 40
    }

    // Middle area is currently empty. It is anchored
    // up-down between filterArea and statusArea
    // and left-right between parents left and colorArea
    ListArea {
        id: listArea
        anchors.top: filterArea.bottom
        anchors.bottom: statusArea.top
        anchors.left: parent.left
        anchors.right: colorArea.left
    }

    // ColorArea could also be sub-element of ListArea
    // as the exercise didn't specify how it'll be used
    // colorArea.selectedColor will be updated when user
    // clicks on one of the colored rectangles.
    ColorArea {
        id: colorArea
        anchors.top: filterArea.bottom
        anchors.bottom: statusArea.top
        anchors.right: parent.right
        width: childrenRect.width

        // Updates filterArea.message (bad...)
        // Better to update status bar directly.
        onSelectedColorChanged: {
            filterArea.message = selectedColor
            console.log(selectedColor)
        }
    }

    // Status area text is bound to filterArea.message
    // A better solution would be to change it via script,
    // since now the ColorArea updates are routed via
    // filterArea.message
    StatusArea {
        id: statusArea
        anchors.bottom: parent.bottom
        anchors.left: parent.left
        anchors.right: parent.right
        height: 25
        text: filterArea.message
    }

}
